@@ -2,6 +2,7 @@
 Contains some common upy project context_processors
 """
 from django.conf import settings
+import upy
 
 def use_upy_admin(request):
     """
@@ -13,4 +14,5 @@ def use_upy_admin(request):
     context_extras['USE_UPY_JQUERY_LIB'] = settings.USE_UPY_JQUERY_LIB
     context_extras['USE_UPY_CSS_RESET'] = settings.USE_UPY_CSS_RESET
     context_extras['USE_UPY_ROSETTA'] = settings.USE_UPY_ROSETTA
+    context_extras['UPY_VERSION'] = upy.__version__
     return context_extras
\ No newline at end of file
